@@ -7,12 +7,13 @@ use Ref::Util qw( is_plain_arrayref );
 use Carp ();
 
 # ABSTRACT: Write Perl extensions using Wasm
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 our %WASM;
 my $linker;
 my %inst;
+my $wasi;
 my @keep;
 
 sub import
@@ -116,6 +117,8 @@ sub import
     }
   }
 
+  Carp::croak("The wasm_ namespace is reserved for internal use") if $package =~ /^wasi_/;
+
   require Wasm::Wasmtime;
   $linker ||= do {
     my $linker = Wasm::Wasmtime::Linker->new(
@@ -123,29 +126,12 @@ sub import
         Wasm::Wasmtime::Engine->new(
           Wasm::Wasmtime::Config
             ->new
-            ->wasm_multi_value(1),
+            ->wasm_multi_value(1)
+            ->cache_config_default,
         ),
       ),
     );
-
     $linker->allow_shadowing(0);
-
-    $linker->define_wasi(
-      Wasm::Wasmtime::WasiInstance->new(
-        $linker->store,
-        'wasi_snapshot_preview1',
-        Wasm::Wasmtime::WasiConfig
-          ->new
-          ->set_argv(@ARGV)
-          ->inherit_env
-          ->inherit_stdin
-          ->inherit_stdout
-          ->inherit_stderr
-          #->preopen_dir ?
-      )
-    );
-    $WASM{wasi_snapshot_preview1} = __FILE__;
-
     $linker;
   };
 
@@ -176,7 +162,37 @@ sub import
   {
 
     my $module = $import->module;
-    next if $module eq 'wasi_snapshot_preview1';
+
+    if($module =~ /^(wasi_unstable|wasi_snapshot_preview1)$/)
+    {
+      next if $WASM{$module};
+      $linker->define_wasi(
+        $wasi ||= Wasm::Wasmtime::WasiInstance->new(
+          $linker->store,
+          $module,
+          Wasm::Wasmtime::WasiConfig
+            ->new
+            ->set_argv($0, @ARGV)
+            ->inherit_env
+            ->inherit_stdin
+            ->inherit_stdout
+            ->inherit_stderr
+            ->preopen_dir("/", "/"),
+        )
+      );
+      $linker->allow_shadowing(1);
+      my $proc_exit = Wasm::Wasmtime::Func->new(
+        $linker->store,
+        ['i32'], [],
+        sub { _wasi_proc_exit($_[0]) },
+      );
+      push @keep, $proc_exit;
+      $linker->define($module, "proc_exit", $proc_exit);
+      $linker->allow_shadowing(0);
+      $WASM{$module} = __FILE__;  # Maybe Wasi::Snapshot::Preview1 etc.
+      next;
+    }
+
     if($module ne 'main')
     {
       my $pm = "$module.pm";
@@ -276,6 +292,13 @@ sub import
       no strict 'refs';
       *{"${package}::$name"} = $global->tie;
     }
+    elsif($kind eq 'memory')
+    {
+      require Wasm::Memory;
+      my $memory = Wasm::Memory->new($extern);
+      no strict 'refs';
+      *{"${package}::$name"} = \$memory;
+    }
   }
 
   if($exporter)
@@ -294,6 +317,16 @@ sub import
   }
 }
 
+# nothing non-standard here right now,
+# but one day we migh want to be able
+# to intercept this and exit out of
+# Wasm, but not out of Perl.
+sub _wasi_proc_exit
+{
+  my($value) = @_;
+  exit($value);
+}
+
 1;
 
 __END__
@@ -308,7 +341,7 @@ Wasm - Write Perl extensions using Wasm
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -347,14 +380,35 @@ mathstuff.pl:
 
 =head1 DESCRIPTION
 
-B<WARNING>: WebAssembly and Wasmtime are a moving target and the interface for these modules
-is under active development.  Use with caution.
+B<WARNING>: WebAssembly and Wasmtime are a moving target and the
+interface for these modules is under active development.  Use with
+caution.
 
-The C<Wasm> Perl dist provides tools for writing Perl bindings using WebAssembly (Wasm).
+The goal of this project is for Perl and WebAssembly to be able to call
+each other transparently without having to know or care which module is
+implemented in which language.  Perl and WebAssembly functions and
+global variables can be imported/exported between Perl and WebAssembly.
+WebAssembly global variables are imported into Perl space as tied scalar
+variables of the same name.  L<Wasm::Memory> provides a Perl interface
+into WebAssembly memory.  L<Wasm::Hook> provides a hook for loading
+WebAssembly files directly with zero Perl wrappers.
 
-The current implementation uses L<Wasm::Wasmtime>, which is itself based on the Rust project
-Wasmtime.  This module doesn't expose the L<Wasm::Wasmtime> interface, and implementation
-could be changed in the future.
+The example above shows WebAssembly Text (WAT) inlined into the
+Perl code for readability. In most cases you will want to compile your
+WebAssembly from a higher level language (Rust, C, Go, etc.), and
+install it alongside your Perl Module (.pm file) and use the C<-self>
+option below.  That is for C<lib/Math.pm> you would install the Wasm
+file into C<lib/Math.wasm>, and use the C<-self> option.
+
+L<Wasm> can optionally L<Exporter> to export WebAssembly functions into
+other modules.  Using C<-export 'ok'> functions can be imported from a
+calling module on requests.  C<-export 'all'> will export all exported
+functions by default.
+
+The current implementation uses L<Wasm::Wasmtime>, which is itself based
+on the Rust project Wasmtime.  This module doesn't expose the
+L<Wasm::Wasmtime> interface, and implementation could be changed in the
+future.
 
 =head1 OPTIONS
 
@@ -362,78 +416,94 @@ could be changed in the future.
 
  use Wasm -api => 0;
 
-As of this writing, since the API is subject to change, this must be provided and set to C<0>.
+As of this writing, since the API is subject to change, this must be
+provided and set to C<0>.
 
 =head2 -exporter
 
  use Wasm -api => 0, -exporter => 'all';
  use Wasm -api => 0, -exporter => 'ok';
 
-Configure the caller as an L<Exporter>, with all the functions in the WebAssembly either C<@EXPORT> (C<all>)
-or C<@EXPORT_OK> (C<ok>).
+Configure the caller as an L<Exporter>, with all the functions in the
+WebAssembly either C<@EXPORT> (C<all>) or C<@EXPORT_OK> (C<ok>).
 
 =head2 -file
 
  use Wasm -api => 0, -file => $file;
 
-Path to a WebAssembly file in either WebAssembly Text (.wat) or WebAssembly binary (.wasm) format.
+Path to a WebAssembly file in either WebAssembly Text (.wat) or
+WebAssembly binary (.wasm) format.
 
 =head2 -package
 
  use Wasm -api => 0, -package => $package;
 
-Install subroutines in to C<$package> namespace instead of the calling namespace.
+Install subroutines in to C<$package> namespace instead of the calling
+namespace.
 
 =head2 -self
 
  use Wasm -api => 0, -self;
 
-Look for a WebAssembly Text (.wat) or WebAssembly binary (.wasm) file with the same base name as
-the Perl source this is called from.
+Look for a WebAssembly Text (.wat) or WebAssembly binary (.wasm) file
+with the same base name as the Perl source this is called from.
 
-For example if you are calling this from C<lib/Foo/Bar.pm>, it will look for C<lib/Foo/Bar.wat> and
-C<lib/Foo/Bar.wasm>.  If both exist, then it will use the newer of the two.
+For example if you are calling this from C<lib/Foo/Bar.pm>, it will look
+for C<lib/Foo/Bar.wat> and C<lib/Foo/Bar.wasm>.  If both exist, then it
+will use the newer of the two.
 
 =head2 -wat
 
  use Wasm -api => 0, -wat => $wat;
 
-String containing WebAssembly Text (WAT).  Helpful for inline WebAssembly inside your Perl source file.
+String containing WebAssembly Text (WAT).  Helpful for inline
+WebAssembly inside your Perl source file.
 
 =head1 GLOBALS
 
 =head2 %Wasm::WASM
 
-This hash maps the Wasm module names to the files from which the Wasm was loaded.
-It is roughly analogous to the C<@INC> array in Perl.
+This hash maps the Wasm module names to the files from which the Wasm
+was loaded. It is roughly analogous to the C<@INC> array in Perl.
 
 =head1 CAVEATS
 
-As mentioned before as of this writing this dist is a work in progress.  I won't intentionally break
-stuff if I don't have to, but practicality may demand it in some situations.
+As mentioned before as of this writing this dist is a work in progress.
+I won't intentionally break stuff if I don't have to, but practicality
+may demand it in some situations.
 
-This interface is implemented using the bundled L<Wasm::Wasmtime> family of modules, which depends
-on the Wasmtime project.
+This interface is implemented using the bundled L<Wasm::Wasmtime> family
+of modules, which depends on the Wasmtime project.
 
-The default way of handling out-of-bounds memory errors is to allocate large C<PROT_NONE> pages at
-startup.  While these pages do not consume many resources in practice (at least in the way that they
-are used by Wasmtime), they can cause out-of-memory errors on Linux systems with virtual memory
-limits (C<ulimi -v> in the C<bash> shell).  Similar techniques are common in other modern programming
-languages, and this is more a limitation of the Linux kernel than anything else.  Setting the limits
-on the virtual memory address size probably doesn't do what you think it is doing and you are probably
-better off finding a way to place limits on process memory.
+The default way of handling out-of-bounds memory errors is to allocate
+large C<PROT_NONE> pages at startup.  While these pages do not consume
+many resources in practice (at least in the way that they are used by
+Wasmtime), they can cause out-of-memory errors on Linux systems with
+virtual memory limits (C<ulimi -v> in the C<bash> shell).  Similar
+techniques are common in other modern programming languages, and this is
+more a limitation of the Linux kernel than anything else.  Setting the
+limits on the virtual memory address size probably doesn't do what you
+think it is doing and you are probably better off finding a way to place
+limits on process memory.
 
-However, as a workaround for environments that choose to set a virtual memory address size limit anyway,
-Wasmtime provides configurations to not allocate the large C<PROT_NONE> pages at some performance
-cost.  The testing plugin L<Test2::Plugin::Wasm> tries to detect environments that have the virtual
-memory address size limits and sets this configuration for you.  For production you can set the
-environment variable C<PERL_WASM_WASMTIME_MEMORY> to tune the appropriate memory settings exactly
-as you want to (see the environment section of L<Wasm::Wasmtime>.
+However, as a workaround for environments that choose to set a virtual
+memory address size limit anyway, Wasmtime provides configurations to
+not allocate the large C<PROT_NONE> pages at some performance cost.  The
+testing plugin L<Test2::Plugin::Wasm> tries to detect environments that
+have the virtual memory address size limits and sets this configuration
+for you.  For production you can set the environment variable
+C<PERL_WASM_WASMTIME_MEMORY> to tune the appropriate memory settings
+exactly as you want to (see the environment section of
+L<Wasm::Wasmtime>.
 
 =head1 SEE ALSO
 
 =over 4
 
+=item L<Wasm::Memory>
+
+Interface to WebAssembly memory from Perl.
+
 =item L<Wasm::Wasmtime>
 
 Low level interface to C<wasmtime>.
