@@ -5,7 +5,7 @@ use warnings;
 use Wasm::Wasmtime::FFI;
 
 # ABSTRACT: Global configuration for Wasm::Wasmtime::Engine
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 $ffi_prefix = 'wasm_config_';
@@ -134,6 +134,21 @@ if(Wasm::Wasmtime::Error->can('new'))
     }
     $self;
   });
+
+
+  $ffi->attach( [ 'wasmtime_config_cache_config_load' => 'cache_config_load' ] => [ 'wasm_config_t', 'string' ] => sub {
+    my($xsub, $self, $value) = @_;
+    Carp::croak("undef passed in as cache config") unless defined $value;
+    $xsub->($self, $value);
+    $self;
+  });
+
+  $ffi->attach( [ 'wasmtime_config_cache_config_load' => 'cache_config_default' ] => [ 'wasm_config_t', 'string' ] => sub {
+    my($xsub, $self) = @_;
+    $xsub->($self, undef);
+    $self;
+  });
+
 }
 else
 {
@@ -152,6 +167,15 @@ else
     }
     $self;
   });
+
+  *cache_config_load    = sub { Carp::croak("property cache_config_load is not available")    };
+
+  *cache_config_default = sub
+  {
+    # silenty ignore
+    my($self) = @_;
+    $self;
+  };
 }
 
 1;
@@ -168,7 +192,7 @@ Wasm::Wasmtime::Config - Global configuration for Wasm::Wasmtime::Engine
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -317,6 +341,18 @@ Acceptable values for C<$profiler> are:
 
 =back
 
+=head2 cache_config_load
+
+ $config->cache_config_load($toml_config);
+
+Path to the cache configuration TOML file.
+
+=head2 cache_config_default
+
+ $config->cache_config_default;
+
+Enable the default caching configuration.
+
 =head1 SEE ALSO
 
 =over 4
