@@ -7,7 +7,7 @@ use Wasm::Wasmtime::FFI;
 use Wasm::Wasmtime::ExternType;
 
 # ABSTRACT: Wasmtime export type class
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 $ffi_prefix = 'wasm_exporttype_';
@@ -52,6 +52,16 @@ $ffi->attach( type => ['wasm_exporttype_t'] => 'wasm_externtype_t' => sub {
   $type;
 });
 
+
+sub to_string
+{
+  my($self) = @_;
+  my $kind   = $self->type->kind;
+  $kind =~ s/type$//;
+  # TODO: escape strings ?
+  sprintf '(%s (export "%s") %s)', $kind, $self->name, $self->type->to_string;
+}
+
 _generate_destroy();
 _generate_vec_class();
 
@@ -69,7 +79,7 @@ Wasm::Wasmtime::ExportType - Wasmtime export type class
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -124,6 +134,12 @@ Returns the name of the export.
 
 Returns the L<Wasm::Wasmtime::ExternType> for the export.
 
+=head2 to_string
+
+ my $string = $exporttype->to_string;
+
+Converts the type into a string for diagnostics.
+
 =head1 SEE ALSO
 
 =over 4
