@@ -10,7 +10,7 @@ require Wasm::Wasmtime::TableType;
 require Wasm::Wasmtime::MemoryType;
 
 # ABSTRACT: Wasmtime extern type class
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 sub kind { die "internal error" };
@@ -43,6 +43,12 @@ $ffi->custom_type('wasm_externtype_t' => {
   },
 });
 
+
+sub to_string
+{
+  die "internal error";  # pure virtual ish
+}
+
 1;
 
 __END__
@@ -57,7 +63,7 @@ Wasm::Wasmtime::ExternType - Wasmtime extern type class
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -128,6 +134,12 @@ Returns true if it is a table type.
 
 Returns true if it is a memory type.
 
+=head2 to_string
+
+ my $string = $externtype->to_string;
+
+Converts the type into a string for diagnostics.
+
 =head1 SEE ALSO
 
 =over 4
