@@ -10,7 +10,7 @@ use constant is_functype => 1;
 use constant kind => 'functype';
 
 # ABSTRACT: Wasmtime function type class
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 $ffi_prefix = 'wasm_functype_';
@@ -50,6 +50,20 @@ $ffi->attach( results => ['wasm_functype_t'] => 'wasm_valtype_vec_t*' => sub {
   $xsub->($self)->to_list;
 });
 
+
+sub to_string
+{
+  my($self) = @_;
+  my @params  = map { $_->to_string } $self->params;
+  my @results = map { $_->to_string } $self->results;
+
+  my $string = '';
+  $string .= "(param @params)" if @params;
+  $string .= ' ' if $string && @results;
+  $string .= "(result @results)" if @results;
+  $string;
+}
+
 __PACKAGE__->_cast(0);
 _generate_destroy();
 
@@ -67,7 +81,7 @@ Wasm::Wasmtime::FuncType - Wasmtime function type class
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -111,6 +125,12 @@ Returns a list of the parameter types for the function type, as L<Wasm::Wasmtime
 
 Returns a list of the result types for the function type, as L<Wasm::Wasmtime::ValType> objects.
 
+=head2 to_string
+
+ my $string = $functype->to_string;
+
+Converts the type into a string for diagnostics.
+
 =head1 SEE ALSO
 
 =over 4
