@@ -11,7 +11,7 @@ use constant is_globaltype => 1;
 use constant kind => 'globaltype';
 
 # ABSTRACT: Wasmtime global type class
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 $ffi_prefix = 'wasm_globaltype_';
@@ -73,6 +73,13 @@ $ffi->attach( mutability => ['wasm_globaltype_t'] => 'uint8' => sub {
   $mutability[$xsub->($self)];
 });
 
+
+sub to_string
+{
+  my($self) = @_;
+  return sprintf("(%s %s)", $self->mutability, $self->content->to_string);
+}
+
 __PACKAGE__->_cast(1);
 _generate_destroy();
 
@@ -90,7 +97,7 @@ Wasm::Wasmtime::GlobalType - Wasmtime global type class
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -141,6 +148,12 @@ Returns the L<Wasm::Wasmtime::ValType> for this global type.
 
 Returns the mutability for this global type.  One of either C<const> or C<var>.
 
+=head2 to_string
+
+ my $string = $globaltype->to_string;
+
+Converts the type into a string for diagnostics.
+
 =head1 SEE ALSO
 
 =over 4
