@@ -8,7 +8,7 @@ use Wasm::Wasmtime::FFI;
 use Wasm::Wasmtime::ExternType;
 
 # ABSTRACT: Wasmtime import type class
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 $ffi_prefix = 'wasm_importtype_';
@@ -68,6 +68,16 @@ $ffi->attach( module => ['wasm_importtype_t'] => 'wasm_byte_vec_t*' => sub {
   $name->get;
 });
 
+
+sub to_string
+{
+  my($self) = @_;
+  my $kind   = $self->type->kind;
+  $kind =~ s/type$//;
+  # TODO: escape strings ?
+  sprintf '(%s (import "%s" "%s") %s)', $kind, $self->module, $self->name, $self->type->to_string;
+}
+
 _generate_destroy();
 _generate_vec_class();
 
@@ -85,7 +95,7 @@ Wasm::Wasmtime::ImportType - Wasmtime import type class
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -141,6 +151,12 @@ Returns the L<Wasm::Wasmtime::ExternType> for the import.
 
 Returns the name of the module for the import.
 
+=head2 to_string
+
+ my $string = $importtype->to_string;
+
+Converts the type into a string for diagnostics.
+
 =head1 SEE ALSO
 
 =over 4
