@@ -3,7 +3,7 @@ package Wasm::Wasmtime::Memory;
 use strict;
 use warnings;
 use base qw( Wasm::Wasmtime::Extern );
-use Ref::Util qw( is_ref );
+use Ref::Util qw( is_ref is_plain_arrayref );
 use Wasm::Wasmtime::FFI;
 use Wasm::Wasmtime::Store;
 use Wasm::Wasmtime::MemoryType;
@@ -11,7 +11,7 @@ use constant is_memory => 1;
 use constant kind => 'memory';
 
 # ABSTRACT: Wasmtime memory class
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 $ffi_prefix = 'wasm_memory_';
@@ -24,6 +24,8 @@ $ffi->attach( new => ['wasm_store_t', 'wasm_memorytype_t'] => 'wasm_memory_t' =>
   if(is_ref $_[0])
   {
     my($store, $memorytype) = @_;
+    $memorytype = Wasm::Wasmtime::MemoryType->new($memorytype)
+      if is_plain_arrayref $memorytype;
     return $xsub->($store, $memorytype);
   }
   else
@@ -85,7 +87,7 @@ Wasm::Wasmtime::Memory - Wasmtime memory class
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
