@@ -9,7 +9,7 @@ use constant is_memorytype => 1;
 use constant kind => 'memorytype';
 
 # ABSTRACT: Wasmtime memory type class
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 $ffi_prefix = 'wasm_memorytype_';
@@ -44,6 +44,16 @@ $ffi->attach( limits => ['wasm_memorytype_t'] => 'uint32[2]' => sub {
   $limits;
 });
 
+
+sub to_string
+{
+  my($self) = @_;
+  my($min, $max) = @{ $self->limits };
+  my $string = "$min";
+  $string .= " $max" if $max != 0xffffffff;
+  return $string;
+}
+
 __PACKAGE__->_cast(3);
 _generate_destroy();
 
@@ -61,7 +71,7 @@ Wasm::Wasmtime::MemoryType - Wasmtime memory type class
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -95,6 +105,12 @@ Creates a new memory type object.
 
 Returns the minimum and maximum number of pages as an array reference.
 
+=head2 to_string
+
+ my $string = $memorytype->to_string;
+
+Converts the type into a string for diagnostics.
+
 =head1 SEE ALSO
 
 =over 4
