@@ -11,7 +11,7 @@ use Wasm::Wasmtime::ExportType;
 use Carp ();
 
 # ABSTRACT: Wasmtime module class
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 $ffi_prefix = 'wasm_module_';
@@ -142,6 +142,20 @@ $ffi->attach( [ imports => '_imports' ] => [ 'wasm_module_t', 'wasm_importtype_v
 
 sub store { shift->{store} }
 
+
+sub to_string
+{
+  my($self) = @_;
+  my @externs = (@{ $self->imports }, @{ $self->exports });
+  return "(module)\n" unless @externs;
+  my $string = "(module\n";
+  foreach my $extern (@externs)
+  {
+    $string .= "  " . $extern->to_string . "\n";
+  }
+  $string .= ")\n";
+}
+
 _generate_destroy();
 
 1;
@@ -158,7 +172,7 @@ Wasm::Wasmtime::Module - Wasmtime module class
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -251,6 +265,12 @@ Returns a list of L<Wasm::Wasmtime::ImportType> objects for the objects imported
 
 Returns the L<Wasm::Wasmtime::Store> object used by this module.
 
+=head2 to_string
+
+ my $string = $module->to_string;
+
+Converts the module imports and exports into a string for diagnostics.
+
 =head1 SEE ALSO
 
 =over 4
