@@ -10,7 +10,7 @@ use constant is_tabletype => 1;
 use constant kind => 'tabletype';
 
 # ABSTRACT: Wasmtime table type class
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 $ffi_prefix = 'wasm_tabletype_';
@@ -62,6 +62,16 @@ $ffi->attach( limits => ['wasm_tabletype_t'] => 'uint32[2]' => sub {
   $xsub->($self);
 });
 
+
+sub to_string
+{
+  my($self) = @_;
+  my($min, $max) = @{ $self->limits };
+  my $string = "$min ";
+  $string .= "$max " if $max != 0xffffffff;
+  $string .= $self->element->to_string;
+}
+
 __PACKAGE__->_cast(2);
 _generate_destroy();
 
@@ -79,7 +89,7 @@ Wasm::Wasmtime::TableType - Wasmtime table type class
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -120,6 +130,12 @@ Returns the L<Wasm::Wasmtime::ValType> for this table type.
 
 Returns the limits as an array reference.
 
+=head2 to_string
+
+ my $string = $tabletype->to_string;
+
+Converts the type into a string for diagnostics.
+
 =head1 SEE ALSO
 
 =over 4
